summaryrefslogtreecommitdiffstats
path: root/examples/dbus/remotecontrolledcar/controller/car_interface.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/dbus/remotecontrolledcar/controller/car_interface.h')
-rw-r--r--examples/dbus/remotecontrolledcar/controller/car_interface.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/dbus/remotecontrolledcar/controller/car_interface.h b/examples/dbus/remotecontrolledcar/controller/car_interface.h
index fadd127460..8d624b3746 100644
--- a/examples/dbus/remotecontrolledcar/controller/car_interface.h
+++ b/examples/dbus/remotecontrolledcar/controller/car_interface.h
@@ -60,14 +60,14 @@
#include <QtDBus/QtDBus>
/*
* Proxy class for interface com.trolltech.Examples.CarInterface
*/
class ComTrolltechExamplesCarInterfaceInterface: public QDBusAbstractInterface
{
Q_OBJECT
public:
static inline const char *staticInterfaceName()
- { return "com.trolltech.Examples.CarInterface"; }
+ { return "org.example.Examples.CarInterface"; }
public:
ComTrolltechExamplesCarInterfaceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);
@@ -60,14 +60,14 @@
#include <QtDBus/QtDBus>
/*
- * Proxy class for interface com.trolltech.Examples.CarInterface
+ * Proxy class for interface org.example.Examples.CarInterface
*/
class ComTrolltechExamplesCarInterfaceInterface: public QDBusAbstractInterface